<a id="widgets.persistent_widgets.*"></a>

## \*

<a id="widgets.persistent_widgets.PersistentCheckBox"></a>

## PersistentCheckBox Objects

```python
class PersistentCheckBox(QCheckBox)
```

<a id="widgets.persistent_widgets.PersistentCheckBox.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, changed=None, *args, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentCheckBox.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentLineEdit"></a>

## PersistentLineEdit Objects

```python
class PersistentLineEdit(QLineEdit)
```

<a id="widgets.persistent_widgets.PersistentLineEdit.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, *args, default='', changed=None, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentLineEdit.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentTextEdit"></a>

## PersistentTextEdit Objects

```python
class PersistentTextEdit(QTextEdit)
```

<a id="widgets.persistent_widgets.PersistentTextEdit.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, *args, default='', changed=None, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentTextEdit.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentListWidget"></a>

## PersistentListWidget Objects

```python
class PersistentListWidget(QListWidget)
```

<a id="widgets.persistent_widgets.PersistentListWidget.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, items=[], default=[], changed=None, *args, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentListWidget.selected_items"></a>

#### selected\_items

```python
def selected_items()
```

<a id="widgets.persistent_widgets.PersistentListWidget.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentTreeWidget"></a>

## PersistentTreeWidget Objects

```python
class PersistentTreeWidget(QTreeWidget)
```

<a id="widgets.persistent_widgets.PersistentTreeWidget.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name,
             items=[],
             index_column=0,
             default=[],
             changed=None,
             *args,
             **kwargs)
```

<a id="widgets.persistent_widgets.PersistentTreeWidget.selected_items"></a>

#### selected\_items

```python
def selected_items()
```

<a id="widgets.persistent_widgets.PersistentTreeWidget.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentComboBox"></a>

## PersistentComboBox Objects

```python
class PersistentComboBox(QComboBox)
```

<a id="widgets.persistent_widgets.PersistentComboBox.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, items=[], changed=None, *args, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentComboBox.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

<a id="widgets.persistent_widgets.PersistentCheckableAction"></a>

## PersistentCheckableAction Objects

```python
class PersistentCheckableAction(QAction)
```

<a id="widgets.persistent_widgets.PersistentCheckableAction.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, *args, **kwargs)
```

<a id="widgets.persistent_widgets.PersistentCheckableAction.restore_state"></a>

#### restore\_state

```python
def restore_state()
```

